@@ -1,22 +1,23 @@
 context("Build ubmsFit object")
 
-on_mac <- tolower(Sys.info()[["sysname"]]) == "darwin"
-on_cran <- !identical(Sys.getenv("NOT_CRAN"), "true")
-skip_if(on_mac & on_cran, "On CRAN mac")
+skip_on_cran()
 
 #Set up a submodel list
 covs <- data.frame(x1=rnorm(3), x2=factor(c("a","b","c")),
                    x3=factor(c("a","b","c")))
-sm1 <- ubmsSubmodel("Det", "det", covs, ~x1+(1|x2), "plogis")
-sm2 <- ubmsSubmodel("Occ", "state", covs, ~x1, "plogis")
-sm3 <- ubmsSubmodel("Occ", "state", covs, ~x1+(1|x2), "plogis")
-sm4 <- ubmsSubmodel("Occ", "state", covs, ~(1|x2)+(1|x3), "plogis")
+pint <- uniform(-5,5)
+pcof <- normal(0,2.5)
+psig <- gamma(1,1)
+sm1 <- ubmsSubmodel("Det", "det", covs, ~x1+(1|x2), "plogis", pint, pcof, psig)
+sm2 <- ubmsSubmodel("Occ", "state", covs, ~x1, "plogis", pint, pcof, psig)
+sm3 <- ubmsSubmodel("Occ", "state", covs, ~x1+(1|x2), "plogis", pint, pcof, psig)
+sm4 <- ubmsSubmodel("Occ", "state", covs, ~(1|x2)+(1|x3), "plogis", pint, pcof, psig)
 
 #Set up response and stan inputs
 umf <- unmarkedFrameOccu(y=matrix(c(1,0,0,1,1,0,0,1,0), nrow=3))
 umf <- process_umf(umf)
-dm <- ubmsSubmodel("Det", "det", obsCovs(umf), ~1, "plogis")
-sm <- ubmsSubmodel("Occ", "state", siteCovs(umf), ~1, "plogis")
+dm <- ubmsSubmodel("Det", "det", obsCovs(umf), ~1, "plogis", pint, pcof, psig)
+sm <- ubmsSubmodel("Occ", "state", siteCovs(umf), ~1, "plogis", pint, pcof, psig)
 sl <- ubmsSubmodelList(sm,dm)
 resp <- ubmsResponse(umf@y,"binomial","binomial",max_primary=1)
 
@@ -66,7 +67,7 @@ test_that("fit_model builds model correctly",{
   ufit <- suppressWarnings(
     fit_model("occu", resp, sl, chains=2, iter=20, refresh=0))
   expect_true(inherits(ufit, "stanfit"))
-  nms <- stanfit_names(sl@submodels)
+  nms <- stanfit_names(sl)
   expect_equal(ufit@sim$fnames_oi[1:length(nms)], nms)
   #Check MCMC options are passed
   arg <- ufit@stan_args
@@ -76,10 +77,18 @@ test_that("fit_model builds model correctly",{
   expect_equal(arg[[1]]$refresh, 0)
 })
 
+test_that("specific model name is shown in console output",{
+  # e.g. 'occu' instead of 'single_season'
+  out <- capture.output(ufit <- suppressWarnings(
+    fit_model("occu", resp, sl, chains=2, iter=20)))
+  expect_true(any(grepl("occu", out)))
+  expect_false(any(grepl("single_season", out)))
+})
+
 test_that("process_stanfit cleans up fitted stan model",{
   expect_true(inherits(sf, "stanfit"))
   psf <- process_stanfit(sf, sl)
-  nms <- stanfit_names(sl@submodels)
+  nms <- stanfit_names(sl)
   expect_equal(psf@sim$fnames_oi[1:length(nms)], nms)
 
   #test model failure
@@ -90,55 +99,33 @@ test_that("process_stanfit cleans up fitted stan model",{
 
 test_that("stanfit_names for params in stan object are correct",{
   sl <- ubmsSubmodelList(sm1, sm2)
-  expect_equal(stanfit_names(sl@submodels),
-    c("beta_det[(Intercept)]", "beta_det[x1]", "beta_state[(Intercept)]",
-      "beta_state[x1]", "b_det[(Intercept) x2:a]", "b_det[(Intercept) x2:b]",
-      "b_det[(Intercept) x2:c]", "sigma_det[(Intercept) x2]"))
+  expect_equal(stanfit_names(sl),
+    c("beta_det[(Intercept)]", "beta_det[x1]", "b_det[(Intercept) x2:a]",
+      "b_det[(Intercept) x2:b]", "b_det[(Intercept) x2:c]",
+      "sigma_det[sigma [1|x2]]", "beta_state[(Intercept)]",
+      "beta_state[x1]"))
 })
 
-test_that("beta names for stanfit are generated correctly",{
-  sl <- ubmsSubmodelList(sm1, sm4)
-  expect_equal(stanfit_beta_names(sl@submodels),
-    c("beta_det[(Intercept)]", "beta_det[x1]",
-      "beta_state[(Intercept)]"))
+test_that("beta names for ubmsSubmodel are generated correctly",{
+  expect_equal(beta_names(sm1), c("(Intercept)", "x1"))
+  expect_equal(beta_names(sm4), c("(Intercept)"))
 })
 
-test_that("b names for stanfit are generated correctly",{
-  sl <- ubmsSubmodelList(sm2, sm2)
-  #No random effects
-  expect_equal(stanfit_b_names(sl@submodels), character(0))
-  #1 model with random effect
-  sl <- ubmsSubmodelList(sm1, sm2)
-  expect_equal(stanfit_b_names(sl@submodels),
-    paste0("b_det[(Intercept) x2:",levels(covs$x2),"]"))
-  #2 models with random effects
-  sl <- ubmsSubmodelList(sm1, sm3)
-  expect_equal(stanfit_b_names(sl@submodels),
-    c(paste0("b_det[(Intercept) x2:",levels(covs$x2),"]"),
-      paste0("b_state[(Intercept) x2:", levels(covs$x2),"]")))
-  #Model with multiple random effects
-  sl <- ubmsSubmodelList(sm1, sm4)
-  expect_equal(stanfit_b_names(sl@submodels),
-    c(paste0("b_det[(Intercept) x2:",levels(covs$x2),"]"),
-      paste0("b_state[(Intercept) x2:", levels(covs$x2),"]"),
-      paste0("b_state[(Intercept) x3:", levels(covs$x3),"]")))
+test_that("b names for ubmsSubmodel are generated correctly",{
+  # No random effect
+  expect_true(is.na(b_names(sm2)))
+  # One random effect
+  expect_equal(b_names(sm1), paste0("(Intercept) x2:",levels(covs$x2)))
+  # Two random effects
+  expect_equal(b_names(sm4), c(paste0("(Intercept) x2:",levels(covs$x2)),
+                              paste0("(Intercept) x3:", levels(covs$x3))))
 })
 
 test_that("sigma names for stanfit are generated correctly",{
-  sl <- ubmsSubmodelList(sm2, sm2)
-  expect_equal(stanfit_sigma_names(sl@submodels), character(0))
-  sl <- ubmsSubmodelList(sm1, sm2)
-  expect_equal(stanfit_sigma_names(sl@submodels),
-               "sigma_det[(Intercept) x2]")
-  sl <- ubmsSubmodelList(sm1, sm3)
-  expect_equal(stanfit_sigma_names(sl@submodels),
-               c("sigma_det[(Intercept) x2]",
-                 "sigma_state[(Intercept) x2]"))
-  sl <- ubmsSubmodelList(sm1, sm4)
-  expect_equal(stanfit_sigma_names(sl@submodels),
-               c("sigma_det[(Intercept) x2]",
-                 "sigma_state[(Intercept) x2]",
-                 "sigma_state[(Intercept) x3]"))
+  # No random effect
+  expect_true(is.na(sigma_names(sm2)))
+  # One random effect
+  expect_equal(sigma_names(sm1), "sigma [1|x2]")
+  # Two random effects
+  expect_equal(sigma_names(sm4), c("sigma [1|x2]", "sigma [1|x3]"))
 })
-
-
