@@ -1,9 +1,6 @@
 context("stan_occuTTD function and methods")
 
-skip_on_cran() # for now
-on_mac <- tolower(Sys.info()[["sysname"]]) == "darwin"
-on_cran <- !identical(Sys.getenv("NOT_CRAN"), "true")
-skip_if(on_mac & on_cran, "On CRAN mac")
+skip_on_cran()
 
 set.seed(123)
 
@@ -77,11 +74,11 @@ test_that("stan_occuTTD produces accurate results",{
                                data=umf, chains=3, iter=300, refresh=0))
   fit_unm <- occuTTD(~elev, detformula=~wind, data=umf)
   #similar to truth
-  expect_equal(as.vector(coef(fit_long))/10, c(beta_psi, beta_lam)/10, tol=0.06)
+  expect_RMSE(coef(fit_long), c(beta_psi, beta_lam), 0.4)
   #similar to unmarked
-  expect_equivalent(as.vector(coef(fit_long))/10, coef(fit_unm)/10, tol=0.03)
+  expect_RMSE(coef(fit_long), coef(fit_unm), 0.1)
   #similar to previous known values
-  expect_equal(as.vector(coef(fit_long)), c(-0.811,0.7002,-1.6653,0.5581), tol=0.05)
+  expect_RMSE(coef(fit_long), c(-0.805,0.714,-1.759,0.694), 0.05)
 })
 
 test_that("stan_occuTTD handles NA values",{
@@ -96,15 +93,15 @@ test_that("stan_occuTTD predict method works",{
   pr <- predict(fit_na, "state")
   expect_is(pr, "data.frame")
   expect_equal(dim(pr), c(10, 4))
-  expect_true(between(pr[1,1], 0, 1))
+  expect_between(pr[1,1], 0, 1)
   pr <- predict(fit_na, "det")
   expect_equal(dim(pr), c(10,4))
-  expect_true(between(pr[1,1], 0, 10))
+  expect_between(pr[1,1], 0, 10)
   #with newdata
   nd <- data.frame(elev=c(0,1))
   pr <- predict(fit_na, "state", newdata=nd)
   expect_equal(dim(pr), c(2,4))
-  expect_true(between(pr[1,1], 0, 1))
+  expect_between(pr[1,1], 0, 1)
 })
 
 test_that("stan_occuTTD getP method works",{
@@ -124,7 +121,7 @@ test_that("stan_occuTTD sim_z method works",{
   expect_is(zz, "matrix")
   expect_equal(dim(zz), c(length(samples), 10))
   expect_equal(unique(as.vector(zz)), c(0,1))
-  expect_true(between(mean(zz), 0, 0.5))
+  expect_between(mean(zz), 0, 0.5)
 
   set.seed(123)
   pz <- posterior_predict(fit, "z", draws=5)
@@ -192,5 +189,22 @@ test_that("Fitted/residual methods work with ubmsFitOccuTTD",{
   expect_is(rp, "gg")
   expect_is(rp2, "gg")
   expect_is(rp3, "gtable")
-  expect_is(mp, "gtable")
+  expect_is(mp, "gg")
+})
+
+test_that("occuTTD spatial works", {
+  skip_on_cran()
+  umf2 <- umf
+  umf2@siteCovs$x <- runif(numSites(umf2), 0, 10)
+  umf2@siteCovs$y <- runif(numSites(umf2), 0, 10)
+
+  fit_spat <- suppressMessages(suppressWarnings(stan_occuTTD(~elev+RSR(x,y,1),
+                                                             detformula=~wind,
+                        data=umf2[1:20,], chains=2, iter=100, refresh=0)))
+
+  expect_is(fit_spat@submodels@submodels$state, "ubmsSubmodelSpatial")
+  expect_equal(names(coef(fit_spat))[3], "state[RSR [tau]]")
+
+  ps <- plot_spatial(fit_spat)
+  expect_is(ps, "gg")
 })
